summaryrefslogtreecommitdiff
path: root/nova/cmd/status.py
diff options
context:
space:
mode:
authorDan Smith <dansmith@redhat.com>2018-02-26 02:10:06 -0800
committerDan Smith <dansmith@redhat.com>2018-03-28 15:58:45 -0700
commita9e7581f00e7f4f70d2193af17025dc18d1d845b (patch)
treea3a4893b220c4096c0c732a5c4dbcb4c74e17241 /nova/cmd/status.py
parent688f93d59f11dab537a2ca51e71b80695b7fc7ac (diff)
downloadnova-a9e7581f00e7f4f70d2193af17025dc18d1d845b.tar.gz
Make get_allocation_candidates() honor aggregate restrictions
This uses the member_of query parameter to placement to ensure that the candidates returned are within the appropriate aggregate(s) if so specified. Related to blueprint placement-req-filter Change-Id: If8ac06039ac9d647efdc088fbe944938e205e941
Diffstat (limited to 'nova/cmd/status.py')
-rw-r--r--nova/cmd/status.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/nova/cmd/status.py b/nova/cmd/status.py
index 2a0e742c2b..7825274601 100644
--- a/nova/cmd/status.py
+++ b/nova/cmd/status.py
@@ -196,11 +196,11 @@ class UpgradeCommands(object):
versions = self._placement_get("/")
max_version = pkg_resources.parse_version(
versions["versions"][0]["max_version"])
# NOTE(mriedem): 1.17 is required by nova-scheduler to get
# allocation candidates with required traits from the flavor.
# NOTE: If you bump this version, remember to update the history
# section in the nova-status man page (doc/source/cli/nova-status).
- needs_version = pkg_resources.parse_version("1.17")
+ needs_version = pkg_resources.parse_version("1.21")
if max_version < needs_version:
msg = (_('Placement API version %(needed)s needed, '
'you have %(current)s.') %
@@ -196,11 +196,11 @@ class UpgradeCommands(object):
max_version = pkg_resources.parse_version(
versions["versions"][0]["max_version"])
- # NOTE(mriedem): 1.17 is required by nova-scheduler to get
- # allocation candidates with required traits from the flavor.
+ # NOTE(mriedem): 1.21 is required by nova-scheduler to be able
+ # to request aggregates.
# NOTE: If you bump this version, remember to update the history
# section in the nova-status man page (doc/source/cli/nova-status).